@@ -49,7 +49,6 @@ struct cryptodev_ctx
   struct session_op sess;
   struct crypt_op cryp;
   uint8_t iv[EALG_MAX_BLOCK_LEN];
-  int reset;
 
   int cfd;
 };
@@ -193,7 +192,7 @@ register_crypto (int cfd)
       if (gnutls_cipher_map[i] == 0)
         continue;
 
-      /* test if a cipher is support it and if yes register it */
+      /* test if a cipher is supported and if yes register it */
       sess.cipher = gnutls_cipher_map[i];
       sess.keylen = gnutls_cipher_get_key_size (i);
       sess.key = fake_key;
@@ -352,10 +351,10 @@ int ret;
 static const gnutls_crypto_mac_st mac_struct = {
   .init = NULL,
   .setkey = NULL,
+  .setnonce = NULL,
   .hash = NULL,
   .output = NULL,
   .deinit = NULL,
-  .reset = NULL,
   .fast = cryptodev_mac_fast
 };
 
@@ -406,7 +405,6 @@ static const gnutls_crypto_digest_st digest_struct = {
   .hash = NULL,
   .output = NULL,
   .deinit = NULL,
-  .reset = NULL,
   .fast = cryptodev_digest_fast
 };
 
