@@ -46,6 +46,8 @@ static const sign_algorithm_st unknown_tls_aid = TLS_SIGN_AID_UNKNOWN;
 static const gnutls_sign_entry sign_algorithms[] = {
   {"RSA-SHA1", SIG_RSA_SHA1_OID, GNUTLS_SIGN_RSA_SHA1, GNUTLS_PK_RSA,
    GNUTLS_DIG_SHA1, {2, 1}},
+  {"RSA-SHA1", ISO_SIG_RSA_SHA1_OID, GNUTLS_SIGN_RSA_SHA1, GNUTLS_PK_RSA,
+   GNUTLS_DIG_SHA1, {2, 1}},
   {"RSA-SHA224", SIG_RSA_SHA224_OID, GNUTLS_SIGN_RSA_SHA224, GNUTLS_PK_RSA,
    GNUTLS_DIG_SHA224, {3, 1}},
   {"RSA-SHA256", SIG_RSA_SHA256_OID, GNUTLS_SIGN_RSA_SHA256, GNUTLS_PK_RSA,
@@ -127,7 +129,7 @@ gnutls_sign_is_secure (gnutls_sign_algorithm_t algorithm)
   GNUTLS_SIGN_ALG_LOOP (dig = p->mac);
   
   if (dig != GNUTLS_DIG_UNKNOWN)
-    return _gnutls_digest_is_secure(dig);
+    return _gnutls_digest_is_secure(mac_to_entry(dig));
 
   return 0;
 }
@@ -290,8 +292,7 @@ _gnutls_tls_aid_to_sign (const sign_algorithm_st * aid)
 {
   gnutls_sign_algorithm_t ret = GNUTLS_SIGN_UNKNOWN;
 
-  if (aid->hash_algorithm == unknown_tls_aid.hash_algorithm &&
-    aid->sign_algorithm == unknown_tls_aid.sign_algorithm)
+  if (memcmp(aid, &unknown_tls_aid, sizeof(*aid))==0)
     return ret;
 
   GNUTLS_SIGN_LOOP (if (p->aid.hash_algorithm == aid->hash_algorithm
