@@ -21,6 +21,11 @@
  */
 
 const char *_gnutls_packet2str (content_type_t packet);
-const char *_gnutls_handshake2str (gnutls_handshake_description_t handshake);
+inline static const char* _gnutls_handshake2str(unsigned x)
+{
+const char* s = gnutls_handshake_description_get_name(x);
+	if (s == NULL) return "Unknown Handshake packet";
+	else return s;
+}
 void _gnutls_dump_mpi (const char *prefix, bigint_t a);
 void _gnutls_dump_vector (const char *prefix, const uint8_t *a, size_t a_size);
