@@ -294,8 +294,9 @@ _gnutls_srtp_send_params (gnutls_session_t session,
   ret = _gnutls_buffer_append_data_prefix(extdata, 8, priv->mki, priv->mki_size);
   if (ret < 0)
     return gnutls_assert_val(ret);
+  total_size += 1 + priv->mki_size;
 
-  return total_size + 1;
+  return total_size;
 }
 
 /**
