@@ -20,10 +20,11 @@
  *
  */
 
-int _gnutls_encrypt (gnutls_session_t session, const uint8_t * headers,
-                     size_t headers_size, const uint8_t * data,
-                     size_t data_size, size_t target_size, uint8_t * ciphertext,
-                     size_t ciphertext_size, content_type_t type,
+int _gnutls_encrypt (gnutls_session_t session, 
+                     const uint8_t * data,
+                     size_t data_size, size_t min_pad,
+                     mbuffer_st* bufel,
+                     content_type_t type,
                      record_parameters_st * params);
 
 int _gnutls_decrypt (gnutls_session_t session,
