@@ -35,6 +35,9 @@
 #include <gnutls_extensions.h>
 #include <gnutls_buffers.h>
 
+static int
+_gnutls_set_kx (gnutls_session_t session, gnutls_kx_algorithm_t algo);
+
 static const char keyexp[] = "key expansion";
 static const int keyexp_length = sizeof (keyexp) - 1;
 
@@ -92,7 +95,7 @@ _gnutls_set_keys (gnutls_session_t session, record_parameters_st * params,
   memcpy (&rrnd[GNUTLS_RANDOM_SIZE],
           session->security_parameters.server_random, GNUTLS_RANDOM_SIZE);
 
-  if (session->security_parameters.version == GNUTLS_SSL3)
+  if (get_num_version(session) == GNUTLS_SSL3)
     {                           /* SSL 3 */
       ret =
         _gnutls_ssl3_generate_random
@@ -236,16 +239,16 @@ _gnutls_epoch_set_cipher_suite (gnutls_session_t session,
   cipher_algo = _gnutls_cipher_suite_get_cipher_algo (suite);
   mac_algo = _gnutls_cipher_suite_get_mac_algo (suite);
 
+  if (_gnutls_cipher_is_ok (cipher_algo) == 0
+      || _gnutls_mac_is_ok (mac_algo) == 0)
+    return gnutls_assert_val (GNUTLS_E_UNWANTED_ALGORITHM);
+
   if (_gnutls_cipher_priority (session, cipher_algo->id) < 0)
     return gnutls_assert_val (GNUTLS_E_UNWANTED_ALGORITHM);
 
   if (_gnutls_mac_priority (session, mac_algo->id) < 0)
     return gnutls_assert_val (GNUTLS_E_UNWANTED_ALGORITHM);
 
-  if (_gnutls_cipher_is_ok (cipher_algo) == 0
-      || _gnutls_mac_is_ok (mac_algo) == 0)
-    return gnutls_assert_val (GNUTLS_E_UNWANTED_ALGORITHM);
-
   params->cipher = cipher_algo;
   params->mac = mac_algo;
 
@@ -321,16 +324,16 @@ _gnutls_epoch_set_keys (gnutls_session_t session, uint16_t epoch)
 
   comp_algo = params->compression_algorithm;
 
+  if (_gnutls_cipher_is_ok (params->cipher) == 0
+      || _gnutls_mac_is_ok (params->mac) == 0)
+    return gnutls_assert_val (GNUTLS_E_UNWANTED_ALGORITHM);
+
   if (_gnutls_cipher_priority (session, params->cipher->id) < 0)
     return gnutls_assert_val (GNUTLS_E_UNWANTED_ALGORITHM);
 
   if (_gnutls_mac_priority (session, params->mac->id) < 0)
     return gnutls_assert_val (GNUTLS_E_UNWANTED_ALGORITHM);
 
-  if (_gnutls_cipher_is_ok (params->cipher) == 0
-      || _gnutls_mac_is_ok (params->mac) == 0)
-    return gnutls_assert_val (GNUTLS_E_UNWANTED_ALGORITHM);
-
   if (_gnutls_compression_is_ok (comp_algo) != 0)
     return gnutls_assert_val (GNUTLS_E_UNKNOWN_COMPRESSION_ALGORITHM);
 
@@ -346,10 +349,12 @@ _gnutls_epoch_set_keys (gnutls_session_t session, uint16_t epoch)
   ret = _gnutls_init_record_state (params, ver, 1, &params->read);
   if (ret < 0)
     return gnutls_assert_val (ret);
+  params->read.new_record_padding = session->security_parameters.new_record_padding;
 
   ret = _gnutls_init_record_state (params, ver, 0, &params->write);
   if (ret < 0)
     return gnutls_assert_val (ret);
+  params->write.new_record_padding = session->security_parameters.new_record_padding;
 
   params->record_sw_size = 0;
 
@@ -382,7 +387,7 @@ _gnutls_set_resumed_parameters (gnutls_session_t session)
   security_parameters_st *dst = &session->security_parameters;
 
   CPY_COMMON;
-  _gnutls_set_current_version(session, src->version);
+  dst->pversion = src->pversion;
 }
 
 /* Sets the current connection session to conform with the
@@ -500,7 +505,7 @@ _gnutls_write_connection_state_init (gnutls_session_t session)
 
 /* Sets the specified kx algorithm into pending session
  */
-int
+static int
 _gnutls_set_kx (gnutls_session_t session, gnutls_kx_algorithm_t algo)
 {
 
