@@ -356,8 +356,10 @@ static const int kx_priority_secure[] = {
 static const int cipher_priority_performance[] = {
   GNUTLS_CIPHER_ARCFOUR_128,
   GNUTLS_CIPHER_AES_128_GCM,
-  GNUTLS_CIPHER_AES_128_CBC,
   GNUTLS_CIPHER_AES_256_GCM,
+  GNUTLS_CIPHER_CAMELLIA_128_GCM,
+  GNUTLS_CIPHER_CAMELLIA_256_GCM,
+  GNUTLS_CIPHER_AES_128_CBC,
   GNUTLS_CIPHER_AES_256_CBC,
   GNUTLS_CIPHER_CAMELLIA_128_CBC,
   GNUTLS_CIPHER_CAMELLIA_256_CBC,
@@ -367,8 +369,10 @@ static const int cipher_priority_performance[] = {
 
 static const int cipher_priority_normal[] = {
   GNUTLS_CIPHER_AES_128_GCM,
-  GNUTLS_CIPHER_AES_128_CBC,
   GNUTLS_CIPHER_AES_256_GCM,
+  GNUTLS_CIPHER_CAMELLIA_128_GCM,
+  GNUTLS_CIPHER_CAMELLIA_256_GCM,
+  GNUTLS_CIPHER_AES_128_CBC,
   GNUTLS_CIPHER_AES_256_CBC,
   GNUTLS_CIPHER_CAMELLIA_128_CBC,
   GNUTLS_CIPHER_CAMELLIA_256_CBC,
@@ -390,20 +394,23 @@ static const int cipher_priority_suiteb192[] = {
 
 
 static const int cipher_priority_secure128[] = {
+  GNUTLS_CIPHER_AES_128_GCM,
+  GNUTLS_CIPHER_CAMELLIA_128_GCM,
   GNUTLS_CIPHER_AES_128_CBC,
   GNUTLS_CIPHER_CAMELLIA_128_CBC,
-  GNUTLS_CIPHER_AES_128_GCM,
+  GNUTLS_CIPHER_AES_256_GCM,
+  GNUTLS_CIPHER_CAMELLIA_256_GCM,
   GNUTLS_CIPHER_AES_256_CBC,
   GNUTLS_CIPHER_CAMELLIA_256_CBC,
-  GNUTLS_CIPHER_AES_256_GCM,
   0
 };
 
 
 static const int cipher_priority_secure192[] = {
+  GNUTLS_CIPHER_AES_256_GCM,
+  GNUTLS_CIPHER_CAMELLIA_256_GCM,
   GNUTLS_CIPHER_AES_256_CBC,
   GNUTLS_CIPHER_CAMELLIA_256_CBC,
-  GNUTLS_CIPHER_AES_256_GCM,
   0
 };
 
@@ -746,6 +753,9 @@ bulk_rmadd_func *func;
  * Some keywords are defined to provide quick access
  * to common preferences.
  *
+ * Unless there is a special need, using "NORMAL" or "NORMAL:%COMPAT" for compatibility 
+ * is recommended.
+ *
  * "PERFORMANCE" means all the "secure" ciphersuites are enabled,
  * limited to 128 bit ciphers and sorted by terms of speed
  * performance.
