@@ -26,6 +26,7 @@
 #include <gnutls_str.h>
 #include <stdarg.h>
 #include <c-ctype.h>
+#include "vasprintf.h"
 
 /* These function are like strcat, strcpy. They only
  * do bound checking (they shouldn't cause buffer overruns),
@@ -600,16 +601,6 @@ gnutls_hex_encode (const gnutls_datum_t * data, char *result,
   return 0;
 }
 
-static int
-hostname_compare_raw (const char *certname,
-                      size_t certnamesize, const char *hostname)
-{
-  if (certnamesize == strlen (hostname)
-      && memcmp (hostname, certname, certnamesize) == 0)
-    return 1;
-  return 0;
-}
-
 
 /* compare hostname against certificate, taking account of wildcards
  * return 1 on success or 0 on error
@@ -623,18 +614,8 @@ int
 _gnutls_hostname_compare (const char *certname,
                           size_t certnamesize, const char *hostname, int level)
 {
-  char *p;
-  unsigned i;
 
-  if (level == 0)
-    {
-      for (i = 0; i < certnamesize; i++)
-        {
-          if (c_isascii (certname[i]) == 0)
-            return hostname_compare_raw (certname, certnamesize, hostname);
-        }
-    }
-  else if (level > 5)
+  if (level > 5)
     return 0;
 
   /* find the first different character */
@@ -650,14 +631,6 @@ _gnutls_hostname_compare (const char *certname,
     {
       /* a wildcard certificate */
 
-      /* ensure that we have at least two domain components after
-       * the wildcard. */
-      p = strrchr(certname, '.');
-      if (p == NULL || strchr(certname, '.') == p || p[1] == 0)
-        {
-          return 0;
-        }
-
       certname++;
       certnamesize--;
 
