@@ -31,16 +31,13 @@
 #include <gnutls/crypto.h>
 
 /* Gnulib portability files. */
-#include <error.h>
-#include <progname.h>
-#include <version-etc.h>
 #include <read-file.h>
 #include <socket.h>
 
 #include <ocsptool-common.h>
 
 #define MAX_BUF 4*1024
-#define HEADER_PATTERN "POST /%s HTTP/1.1\r\n" \
+#define HEADER_PATTERN "POST / HTTP/1.1\r\n" \
   "Host: %s\r\n" \
   "Accept: */*\r\n" \
   "Content-Type: application/ocsp-request\r\n" \
@@ -49,23 +46,18 @@
 static char buffer[MAX_BUF + 1];
 
 /* returns the host part of a URL */
-static const char* host_from_url(const char* url, unsigned int* port, const char **path)
+static const char* host_from_url(const char* url, unsigned int* port)
 {
 static char hostname[512];
 char * p;
 
   *port = 0;
-  *path = "";
 
   if ((p=strstr(url, "http://")) != NULL)
     {
       snprintf(hostname, sizeof(hostname), "%s", p+7);
       p = strchr(hostname, '/');
-      if (p != NULL)
-        {
-          *p = 0;
-          *path = p+1;
-        }
+      if (p != NULL) *p = 0;
 
       p = strchr(hostname, ':');
       if (p != NULL) {
@@ -90,12 +82,18 @@ _generate_request (gnutls_x509_crt_t cert, gnutls_x509_crt_t issuer,
 
   ret = gnutls_ocsp_req_init (&req);
   if (ret < 0)
-    error (EXIT_FAILURE, 0, "ocsp_req_init: %s", gnutls_strerror (ret));
+    {
+      fprintf( stderr, "ocsp_req_init: %s", gnutls_strerror (ret));
+      exit(1);
+    }
 
   ret = gnutls_ocsp_req_add_cert (req, GNUTLS_DIG_SHA1,
   				      issuer, cert);
   if (ret < 0)
-    error (EXIT_FAILURE, 0, "ocsp_req_add_cert: %s", gnutls_strerror (ret));
+    {
+      fprintf( stderr, "ocsp_req_add_cert: %s", gnutls_strerror (ret));
+      exit(1);
+    }
     
   if (nonce)
     {
@@ -104,17 +102,26 @@ _generate_request (gnutls_x509_crt_t cert, gnutls_x509_crt_t issuer,
 
       ret = gnutls_rnd (GNUTLS_RND_RANDOM, nonce.data, nonce.size);
       if (ret < 0)
-	error (EXIT_FAILURE, 0, "gnutls_rnd: %s", gnutls_strerror (ret));
+	{
+	  fprintf( stderr, "gnutls_rnd: %s", gnutls_strerror (ret));
+          exit(1);
+        }
 
       ret = gnutls_ocsp_req_set_nonce (req, 0, &nonce);
       if (ret < 0)
-	error (EXIT_FAILURE, 0, "ocsp_req_set_nonce: %s",
+	{
+	  fprintf( stderr, "ocsp_req_set_nonce: %s",
 	       gnutls_strerror (ret));
+          exit(1);
+        }
     }
 
   ret = gnutls_ocsp_req_export (req, rdata);
   if (ret != 0)
-    error (EXIT_FAILURE, 0, "ocsp_req_export: %s", gnutls_strerror (ret));
+    {
+      fprintf( stderr, "ocsp_req_export: %s", gnutls_strerror (ret));
+      exit(1);
+    }
 
   gnutls_ocsp_req_deinit (req);
   return;
@@ -151,7 +158,7 @@ char* url = (void*)server;
 char headers[1024];
 char service[16];
 unsigned char * p;
-const char *hostname, *path;
+const char *hostname;
 unsigned int headers_size = 0, port;
 socket_st hd;
 
@@ -181,7 +188,7 @@ socket_st hd;
       gnutls_free(data.data);
     }
     
-  hostname = host_from_url(url, &port, &path);
+  hostname = host_from_url(url, &port);
   if (port != 0)
     snprintf(service, sizeof(service), "%u", port);
   else strcpy(service, "80");
@@ -192,7 +199,7 @@ socket_st hd;
 
   _generate_request(cert, issuer, &req, nonce);
 
-  snprintf(headers, sizeof(headers), HEADER_PATTERN, path, hostname, (unsigned int)req.size);
+  snprintf(headers, sizeof(headers), HEADER_PATTERN, hostname, (unsigned int)req.size);
   headers_size = strlen(headers);
   
   socket_open(&hd, hostname, service, 0);
@@ -328,11 +335,17 @@ check_ocsp_response (gnutls_x509_crt_t cert,
 
   ret = gnutls_ocsp_resp_init (&resp);
   if (ret < 0)
-    error (EXIT_FAILURE, 0, "ocsp_resp_init: %s", gnutls_strerror (ret));
+    {
+      fprintf(stderr,  "ocsp_resp_init: %s", gnutls_strerror (ret));
+      exit(1);
+    }
 
   ret = gnutls_ocsp_resp_import (resp, data);
   if (ret < 0)
-    error (EXIT_FAILURE, 0, "importing response: %s", gnutls_strerror (ret));
+    {
+      fprintf(stderr,  "importing response: %s", gnutls_strerror (ret));
+      exit(1);
+    }
   
   ret = gnutls_ocsp_resp_check_crt(resp, 0, cert);
   if (ret < 0)
@@ -344,8 +357,11 @@ check_ocsp_response (gnutls_x509_crt_t cert,
 
   ret = gnutls_ocsp_resp_verify_direct( resp, issuer, &status, 0);
   if (ret < 0)
-    error (EXIT_FAILURE, 0, "gnutls_ocsp_resp_verify_direct: %s",
-      gnutls_strerror (ret));
+    {  
+      fprintf(stderr,  "gnutls_ocsp_resp_verify_direct: %s",
+        gnutls_strerror (ret));
+      exit(1);
+    }
 
   if (status != 0)
     {
@@ -364,7 +380,10 @@ check_ocsp_response (gnutls_x509_crt_t cert,
   ret = gnutls_ocsp_resp_get_single(resp, 0, NULL, NULL, NULL, NULL,
         &cert_status, &vtime, &ntime, &rtime, NULL);
   if (ret < 0)
-    error (EXIT_FAILURE, 0, "reading response: %s", gnutls_strerror (ret));
+    {
+      fprintf(stderr,  "reading response: %s", gnutls_strerror (ret));
+      exit(1);
+    }
   
   if (cert_status == GNUTLS_OCSP_CERT_REVOKED)
     {
