@@ -30,6 +30,8 @@ void pkcs11_list (FILE * outfile, const char *url, int type,
                   common_info_st *);
 void pkcs11_mechanism_list (FILE * outfile, const char *url,
                             unsigned int login, common_info_st *);
+void pkcs11_get_random (FILE * outfile, const char *url,
+                            unsigned bytes, common_info_st *);
 void pkcs11_export (FILE * outfile, const char *pkcs11_url,
                     unsigned int login, common_info_st *);
 void pkcs11_token_list (FILE * outfile, unsigned int detailed,
