@@ -34,18 +34,18 @@
 #include <common.h>
 
 void
-pkcs11_delete (FILE * outfile, const char *url, int batch, unsigned int login_flags,
+pkcs11_delete (FILE * outfile, const char *url, int batch, unsigned int login,
                common_info_st * info)
 {
   int ret;
   unsigned int obj_flags = 0;
 
-  if (login_flags)
-    obj_flags = login_flags;
+  if (login)
+    obj_flags = GNUTLS_PKCS11_OBJ_FLAG_LOGIN;
 
   if (!batch)
     {
-      pkcs11_list (outfile, url, PKCS11_TYPE_ALL, login_flags,
+      pkcs11_list (outfile, url, PKCS11_TYPE_ALL, login,
                    GNUTLS_PKCS11_URL_LIB, info);
       ret =
         read_yesno ("Are you sure you want to delete those objects? (y/N): ", 0);
@@ -71,7 +71,7 @@ pkcs11_delete (FILE * outfile, const char *url, int batch, unsigned int login_fl
 /* lists certificates from a token
  */
 void
-pkcs11_list (FILE * outfile, const char *url, int type, unsigned int login_flags,
+pkcs11_list (FILE * outfile, const char *url, int type, unsigned int login,
              unsigned int detailed, common_info_st * info)
 {
   gnutls_pkcs11_obj_t *crt_list;
@@ -81,8 +81,8 @@ pkcs11_list (FILE * outfile, const char *url, int type, unsigned int login_flags
   int attrs;
   unsigned int obj_flags = 0;
 
-  if (login_flags)
-    obj_flags = login_flags;
+  if (login)
+    obj_flags = GNUTLS_PKCS11_OBJ_FLAG_LOGIN;
 
   pkcs11_common ();
 
@@ -175,7 +175,7 @@ pkcs11_list (FILE * outfile, const char *url, int type, unsigned int login_flags
 }
 
 void
-pkcs11_export (FILE * outfile, const char *url, unsigned int login_flags,
+pkcs11_export (FILE * outfile, const char *url, unsigned int login,
                common_info_st * info)
 {
   gnutls_pkcs11_obj_t crt;
@@ -185,8 +185,8 @@ pkcs11_export (FILE * outfile, const char *url, unsigned int login_flags,
   size_t size;
   unsigned int obj_flags = 0;
 
-  if (login_flags)
-    obj_flags = login_flags;
+  if (login)
+    obj_flags = GNUTLS_PKCS11_OBJ_FLAG_LOGIN;
 
   pkcs11_common ();
 
@@ -396,7 +396,7 @@ pkcs11_token_list (FILE * outfile, unsigned int detailed,
 void
 pkcs11_write (FILE * outfile, const char *url, const char *label, 
               int trusted, int private,
-              unsigned int login_flags, common_info_st * info)
+              unsigned int login, common_info_st * info)
 {
   gnutls_x509_crt_t xcrt;
   gnutls_x509_privkey_t xkey;
@@ -405,8 +405,8 @@ pkcs11_write (FILE * outfile, const char *url, const char *label,
   unsigned int key_usage = 0;
   gnutls_datum_t *secret_key;
 
-  if (login_flags)
-    flags = login_flags;
+  if (login)
+    flags = GNUTLS_PKCS11_OBJ_FLAG_LOGIN;
 
   pkcs11_common ();
 
@@ -437,15 +437,13 @@ pkcs11_write (FILE * outfile, const char *url, const char *label,
   if (xcrt != NULL)
     {
       if (trusted)
-        flags |= GNUTLS_PKCS11_OBJ_FLAG_MARK_TRUSTED;
+        flags |= GNUTLS_PKCS11_OBJ_FLAG_MARK_TRUSTED|GNUTLS_PKCS11_OBJ_FLAG_LOGIN_SO;
 
       ret = gnutls_pkcs11_copy_x509_crt (url, xcrt, label, flags);
       if (ret < 0)
         {
           fprintf (stderr, "Error in %s:%d: %s\n", __func__, __LINE__,
                    gnutls_strerror (ret));
-          if (trusted && (flags & GNUTLS_PKCS11_OBJ_FLAG_LOGIN_SO) == 0)
-            fprintf(stderr, "note: some tokens may require security officer login for this operation\n");
           exit (1);
         }
 
@@ -481,14 +479,14 @@ void
 pkcs11_generate (FILE * outfile, const char *url, gnutls_pk_algorithm_t pk,
               unsigned int bits,
               const char *label, int private, int detailed,
-              unsigned int login_flags, common_info_st * info)
+              unsigned int login, common_info_st * info)
 {
   int ret;
   unsigned int flags = 0;
   gnutls_datum_t pubkey;
 
-  if (login_flags)
-    flags = login_flags;
+  if (login)
+    flags = GNUTLS_PKCS11_OBJ_FLAG_LOGIN;
 
   pkcs11_common ();
 
@@ -506,7 +504,7 @@ pkcs11_generate (FILE * outfile, const char *url, gnutls_pk_algorithm_t pk,
     {
       fprintf (stderr, "Error in %s:%d: %s\n", __func__, __LINE__,
                gnutls_strerror (ret));
-      if (login_flags == 0)
+      if (login == 0)
         fprintf(stderr, "Note that --login was not specified and it may be required for generation.\n");
       else if (bits != 1024)
         fprintf (stderr, "Note that several smart cards do not support arbitrary size keys.\nTry --bits 1024 or 2048.\n");
@@ -781,7 +779,7 @@ const char *mech_list[] = {
 };
 
 void
-pkcs11_mechanism_list (FILE * outfile, const char *url, unsigned int login_flags,
+pkcs11_mechanism_list (FILE * outfile, const char *url, unsigned int login,
                        common_info_st * info)
 {
   int ret;
@@ -812,5 +810,35 @@ pkcs11_mechanism_list (FILE * outfile, const char *url, unsigned int login_flags
   while (ret >= 0);
 
 
+  return;
+}
+
+void
+pkcs11_get_random (FILE * outfile, const char *url, unsigned bytes, common_info_st * info)
+{
+  int ret;
+  uint8_t* output;
+
+  pkcs11_common ();
+
+  if (url == NULL)
+    url = "pkcs11:";
+
+  output = malloc(bytes);
+  if (output == NULL)
+    {
+      fprintf(stderr, "Memory error\n");
+      exit(1);
+    }
+
+  ret = gnutls_pkcs11_token_get_random (url, output, bytes);
+  if (ret < 0)
+    {
+      fprintf(stderr, "gnutls_pkcs11_token_get_random: %s\n", gnutls_strerror(ret));
+      exit(1);
+    }
+
+  fwrite(output, 1, bytes, outfile);
+
   return;
 }
