@@ -109,7 +109,7 @@ client (int fd, int server_init)
      */
     gnutls_credentials_set (session, GNUTLS_CRD_ANON, anoncred);
 
-    gnutls_transport_set_ptr (session, (gnutls_transport_ptr_t) fd);
+    gnutls_transport_set_int (session, fd);
 
     /* Perform the TLS handshake
      */
@@ -248,7 +248,7 @@ server (int fd, int server_init)
     session = initialize_tls_session ();
     gnutls_credentials_set (session, GNUTLS_CRD_ANON, anoncred);
 
-    gnutls_transport_set_ptr (session, (gnutls_transport_ptr_t) fd);
+    gnutls_transport_set_int (session, fd);
 
     do
       {
