@@ -121,7 +121,7 @@ client (int fd, int profile)
      */
     gnutls_credentials_set (session, GNUTLS_CRD_ANON, anoncred);
 
-    gnutls_transport_set_ptr (session, (gnutls_transport_ptr_t) fd);
+    gnutls_transport_set_int (session, fd);
 
     /* Perform the TLS handshake
      */
@@ -243,7 +243,7 @@ server (int fd, int profile)
 
     gnutls_credentials_set (session, GNUTLS_CRD_ANON, anoncred);
 
-    gnutls_transport_set_ptr (session, (gnutls_transport_ptr_t) fd);
+    gnutls_transport_set_int (session, fd);
 
     do
       {
@@ -313,7 +313,7 @@ start (int profile)
     int fd[2];
     int ret;
 
-    ret = socketpair (AF_UNIX, SOCK_DGRAM, 0, fd);
+    ret = socketpair (AF_UNIX, SOCK_STREAM, 0, fd);
     if (ret < 0)
       {
           perror ("socketpair");
