@@ -152,7 +152,7 @@ client (int fd, int packet)
   counter = 0;
   packet_to_lose = packet;
 
-  gnutls_transport_set_ptr (session, (gnutls_transport_ptr_t) fd);
+  gnutls_transport_set_int (session, fd);
   gnutls_transport_set_push_function (session, push);
 
   /* Perform the TLS handshake
@@ -226,7 +226,7 @@ int ret;
   counter = 0;
   packet_to_lose = packet;
 
-  gnutls_transport_set_ptr (session, (gnutls_transport_ptr_t) fd);
+  gnutls_transport_set_int (session, fd);
   gnutls_transport_set_push_function (session, push);
 
   do 
@@ -253,7 +253,7 @@ static void start (int server_packet, int client_packet)
     fprintf(stderr, "\nWill discard %s packet %d\n", 
       (client_packet!=-1)?"client":"server", (client_packet!=-1)?client_packet:server_packet);
   
-  ret = socketpair(AF_UNIX, SOCK_DGRAM, 0, fd);
+  ret = socketpair(AF_UNIX, SOCK_STREAM, 0, fd);
   if (ret < 0)
     {
       perror("socketpair");
