@@ -152,7 +152,7 @@ client (int fd, const char* prio, unsigned overhead)
   gnutls_credentials_set (session, GNUTLS_CRD_ANON, anoncred);
   gnutls_credentials_set (session, GNUTLS_CRD_CERTIFICATE, x509_cred);
 
-  gnutls_transport_set_ptr (session, (gnutls_transport_ptr_t) fd);
+  gnutls_transport_set_int (session, fd);
 
   /* Perform the TLS handshake
    */
@@ -254,7 +254,7 @@ gnutls_session_t session;
 
   session = initialize_tls_session (prio);
 
-  gnutls_transport_set_ptr (session, (gnutls_transport_ptr_t) fd);
+  gnutls_transport_set_int (session, fd);
 
   do 
     {
@@ -348,7 +348,7 @@ doit (void)
   /* 13 + 20(sha1) + 16(iv) + 16(max pad) */
   start("NONE:+VERS-DTLS1.0:+AES-128-CBC:+SHA1:+SIGN-ALL:+COMP-NULL:+RSA", 65);
   /* 13 + 16(tag) + 4(iv) */
-  start("NONE:+VERS-DTLS1.0:+AES-128-GCM:+AEAD:+SIGN-ALL:+COMP-NULL:+RSA", 33);
+  start("NONE:+VERS-DTLS1.0:+AES-128-GCM:+AEAD:+SIGN-ALL:+COMP-NULL:+RSA", 37);
   /* 13 + 20(tag) */
   start("NONE:+VERS-DTLS1.0:+SALSA20-256:+SHA1:+SIGN-ALL:+COMP-NULL:+RSA", 33);
   /* 13 + 12(tag) */
