@@ -39,10 +39,12 @@
 #include "../eagain-common.h"
 #include "../utils.h"
 
+const char* side = "";
+
 static void
 tls_log_func (int level, const char *str)
 {
-  fprintf (stderr, "|<%d>| %s", level, str);
+  fprintf (stderr, "%s|<%d>| %s", side, level, str);
 }
 
 static unsigned char server_cert_pem[] =
@@ -98,7 +100,7 @@ void doit(void)
   int cret = GNUTLS_E_AGAIN;
 
   /* General init. */
-  gnutls_global_init ();
+  global_init ();
   gnutls_global_set_log_function (tls_log_func);
   if (debug) gnutls_global_set_log_level (2);
 
@@ -112,7 +114,7 @@ void doit(void)
   gnutls_priority_set_direct (server, "NORMAL", NULL);
   gnutls_transport_set_push_function (server, server_push);
   gnutls_transport_set_pull_function (server, server_pull);
-  gnutls_transport_set_ptr (server, (gnutls_transport_ptr_t)server);
+  gnutls_transport_set_ptr (server, server);
 
   /* Init client */
   gnutls_certificate_allocate_credentials (&clientx509cred);
@@ -122,7 +124,7 @@ void doit(void)
                               NULL);
   gnutls_transport_set_push_function (client, client_push);
   gnutls_transport_set_pull_function (client, client_pull);
-  gnutls_transport_set_ptr (client, (gnutls_transport_ptr_t)client);
+  gnutls_transport_set_ptr (client, client);
 
   HANDSHAKE(client, server);
 
