@@ -101,7 +101,7 @@ void doit(void)
   int cret = GNUTLS_E_AGAIN;
 
   /* General init. */
-  gnutls_global_init ();
+  global_init ();
   gnutls_global_set_log_function (tls_log_func);
   if (debug) gnutls_global_set_log_level (2);
 
@@ -116,7 +116,7 @@ void doit(void)
                               NULL);
   gnutls_transport_set_push_function (server, server_push);
   gnutls_transport_set_pull_function (server, server_pull);
-  gnutls_transport_set_ptr (server, (gnutls_transport_ptr_t)server);
+  gnutls_transport_set_ptr (server, server);
 
   /* Init client */
   gnutls_certificate_allocate_credentials (&clientx509cred);
@@ -125,7 +125,7 @@ void doit(void)
   gnutls_priority_set_direct (client, "NORMAL", NULL);
   gnutls_transport_set_push_function (client, client_push);
   gnutls_transport_set_pull_function (client, client_pull);
-  gnutls_transport_set_ptr (client, (gnutls_transport_ptr_t)client);
+  gnutls_transport_set_ptr (client, client);
 
   HANDSHAKE(client, server);
 
