@@ -152,7 +152,7 @@ client (int sd)
    */
   gnutls_credentials_set (session, GNUTLS_CRD_CERTIFICATE, xcred);
 
-  gnutls_transport_set_ptr (session, (gnutls_transport_ptr_t) sd);
+  gnutls_transport_set_int (session, sd);
 
   /* Perform the TLS handshake
    */
@@ -371,7 +371,7 @@ server (int sd)
 
   session = initialize_tls_session ();
 
-  gnutls_transport_set_ptr (session, (gnutls_transport_ptr_t) sd);
+  gnutls_transport_set_int (session, sd);
   ret = gnutls_handshake (session);
   if (ret < 0)
     {
